/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::gasoline

Description
    iso-Octane

SourceFiles
    gasoline.C

\*---------------------------------------------------------------------------*/

#ifndef gasoline_H
#define gasoline_H

#include "liquid.H"
#include "NSRDSfunc0.H"
#include "NSRDSfunc1.H"
#include "NSRDSfunc2.H"
#include "NSRDSfunc3.H"
#include "NSRDSfunc4.H"
#include "NSRDSfunc5.H"
#include "NSRDSfunc6.H"
#include "NSRDSfunc7.H"
#include "NSRDSfunc14.H"
#include "APIdiffCoefFunc.H"

#include "NSRDSfuncgRho.H"
#include "NSRDSfuncgPv.H"
#include "NSRDSfuncgHl.H"
#include "NSRDSfuncgCp.H"
#include "NSRDSfuncgH.H"
#include "NSRDSfuncgCpg.H"
#include "NSRDSfuncgMu.H"
#include "NSRDSfuncgK.H"
#include "NSRDSfuncgSigma.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class gasoline Declaration
\*---------------------------------------------------------------------------*/

class gasoline
:
    public liquid
{
    // Private data

        NSRDSfuncgRho rho_;
        NSRDSfuncgPv pv_;
        NSRDSfuncgHl hl_;
        NSRDSfuncgCp cp_;
        NSRDSfuncgH h_;
        NSRDSfuncgCpg cpg_;
        NSRDSfunc4 B_;
        NSRDSfuncgMu mu_;
        NSRDSfunc2 mug_;
        NSRDSfuncgK K_;
        NSRDSfunc2 Kg_;
        NSRDSfuncgSigma sigma_;
        APIdiffCoefFunc D_;


public:

    //- Runtime type information
    TypeName("gasoline");


    // Constructors

        //- Construct null
        gasoline();

        //- Construct from components
        gasoline
        (
            const liquid& l,
            const NSRDSfuncgRho& density,
            const NSRDSfuncgPv& vapourPressure,
            const NSRDSfuncgHl& heatOfVapourisation,
            const NSRDSfuncgCp& heatCapacity,
            const NSRDSfuncgH& enthalpy,
            const NSRDSfuncgCpg& idealGasHeatCapacity,
            const NSRDSfunc4& secondVirialCoeff,
            const NSRDSfuncgMu& dynamicViscosity,
            const NSRDSfunc2& vapourDynamicViscosity,
            const NSRDSfuncgK& thermalConductivity,
            const NSRDSfunc2& vapourThermalConductivity,
            const NSRDSfuncgSigma& surfaceTension,
            const APIdiffCoefFunc& vapourDiffussivity
        );

        //- Construct from Istream
        gasoline(Istream& is);


    // Member Functions

        //- Liquid density [kg/m^3]
        inline scalar rho(scalar p, scalar T) const;

        //- Vapour pressure [Pa]
        inline scalar pv(scalar p, scalar T) const;

        //- Heat of vapourisation [J/kg]
        inline scalar hl(scalar p, scalar T) const;

        //- Liquid heat capacity [J/(kg K)]
        inline scalar cp(scalar p, scalar T) const;

        //- Liquid Enthalpy [J/(kg)]
        inline scalar h(scalar p, scalar T) const;

        //- Ideal gas heat capacity [J/(kg K)]
        inline scalar cpg(scalar p, scalar T) const;

        //- Second Virial Coefficient [m^3/kg]
        inline scalar B(scalar p, scalar T) const;

        //- Liquid viscosity [Pa s]
        inline scalar mu(scalar p, scalar T) const;

        //- Vapour viscosity [Pa s]
        inline scalar mug(scalar p, scalar T) const;

        //- Liquid thermal conductivity [W/(m K)]
        inline scalar K(scalar p, scalar T) const;

        //- Vapour thermal conductivity [W/(m K)]
        inline scalar Kg(scalar p, scalar T) const;

        //- Surface tension [N/m]
        inline scalar sigma(scalar p, scalar T) const;

        //- Vapour diffussivity [m2/s]
        inline scalar D(scalar p, scalar T) const;


    // I-O

        //- Write the function coefficients
        void writeData(Ostream& os) const
        {
            liquid::writeData(os); os << nl;
            rho_.writeData(os); os << nl;
            pv_.writeData(os); os << nl;
            hl_.writeData(os); os << nl;
            cp_.writeData(os); os << nl;
            cpg_.writeData(os); os << nl;
            B_.writeData(os); os << nl;
            mu_.writeData(os); os << nl;
            mug_.writeData(os); os << nl;
            K_.writeData(os); os << nl;
            Kg_.writeData(os); os << nl;
            sigma_.writeData(os); os << nl;
            D_.writeData(os); os << endl;
        }

        //- Ostream Operator
        friend Ostream& operator<<(Ostream& os, const gasoline& l)
        {
            l.writeData(os);
            return os;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#include "gasolineI.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
