/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::NSRDSfuncgRho

Description
    NSRDS function number 105

    Source:
    @verbatim
                      NSRDS - AICHE
                 Data Compilation Tables
                    of Properties of
                     Pure Compounds

        Design Institute for Physical Property Data
          American Institute of Chemical Engineers
                  345 East 47th Street
                New York, New York 10017

         National Standard Reference Data System
         American Institute of Chemical Engineers

          T.E. Daubert       -       R.P. Danner

            Department of Chemical Engineering
            The Pennsylvania State University
                University Park, PA 16802
    @endverbatim

\*---------------------------------------------------------------------------*/

#ifndef NSRDSfuncgRho_H
#define NSRDSfuncgRho_H

#include "thermophysicalFunction.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class NSRDSfuncgRho Declaration
\*---------------------------------------------------------------------------*/

class NSRDSfuncgRho
:
    public thermophysicalFunction
{
    // Private data

        // NSRDS function 105 coefficients
        scalar a_, b_, c_, d_;
        scalar rho[56];


public:

    //- Runtime type information
    TypeName("NSRDSfuncgRho");


    // Constructors

        //- Construct from components
        NSRDSfuncgRho(scalar a, scalar b, scalar c, scalar d)
        :
            a_(a),
            b_(b),
            c_(c),
            d_(d)
        {}

        //- Construct from Istream
        NSRDSfuncgRho(Istream& is)
        :
            a_(readScalar(is)),
            b_(readScalar(is)),
            c_(readScalar(is)),
            d_(readScalar(is))
        {}

        //- Construct from null & initialize from table
        NSRDSfuncgRho() {
            rho[0] = 9.53673e+02;
            rho[1] = 9.48499e+02;
            rho[2] = 9.43127e+02;
            rho[3] = 9.37560e+02;
            rho[4] = 9.31801e+02;
            rho[5] = 9.25855e+02;
            rho[6] = 9.19726e+02;
            rho[7] = 9.13417e+02;
            rho[8] = 9.06934e+02;
            rho[9] = 9.00280e+02;
            rho[10] = 8.93461e+02;
            rho[11] = 8.86479e+02;
            rho[12] = 8.79341e+02;
            rho[13] = 8.72050e+02;
            rho[14] = 8.64612e+02;
            rho[15] = 8.57031e+02;
            rho[16] = 8.49313e+02;
            rho[17] = 8.41461e+02;
            rho[18] = 8.33482e+02;
            rho[19] = 8.25380e+02;
            rho[20] = 8.17160e+02;
            rho[21] = 8.08827e+02;
            rho[22] = 8.00387e+02;
            rho[23] = 7.91844e+02;
            rho[24] = 7.83204e+02;
            rho[25] = 7.74473e+02;
            rho[26] = 7.65654e+02;
            rho[27] = 7.56754e+02;
            rho[28] = 7.47777e+02;
            rho[29] = 7.38729e+02;
            rho[30] = 7.29615e+02;
            rho[31] = 7.20441e+02;
            rho[32] = 7.11210e+02;
            rho[33] = 7.01929e+02;
            rho[34] = 6.92603e+02;
            rho[35] = 6.83236e+02;
            rho[36] = 6.73834e+02;
            rho[37] = 6.64401e+02;
            rho[38] = 6.54943e+02;
            rho[39] = 6.45464e+02;
            rho[40] = 6.35970e+02;
            rho[41] = 6.26464e+02;
            rho[42] = 6.16953e+02;
            rho[43] = 6.07439e+02;
            rho[44] = 5.97928e+02;
            rho[45] = 5.88425e+02;
            rho[46] = 5.78934e+02;
            rho[47] = 5.69458e+02;
            rho[48] = 5.60003e+02;
            rho[49] = 5.50573e+02;
            rho[50] = 5.41171e+02;
            rho[51] = 5.31802e+02;
            rho[52] = 5.22470e+02;
            rho[53] = 5.13177e+02;
            rho[54] = 5.03929e+02;
            rho[55] = 4.94729e+02;
	}

    // Member Functions

        //- Evaluate the function and return the result
        scalar f(scalar, scalar T) const
        {
	    scalar rho_ = 0.0;
	    for(int i=0; i<55; i++){
		   if(T>=10*i && T<10*(i+1)){
		   	rho_ = rho[i]+(T-10*i)*(rho[i+1]-rho[i])/10;
		   	break;
			}
		   }
	    return rho_;
        }


        //- Write the function coefficients
        void writeData(Ostream& os) const
        {
            os  << a_ << token::SPACE
                << b_ << token::SPACE
                << c_ << token::SPACE
                << d_;
        }


    // Ostream Operator

        friend Ostream& operator<<(Ostream& os, const NSRDSfuncgRho& f)
        {
            f.writeData(os);
            return os;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
