/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::NSRDSfuncgSigma

Description
    NSRDS function number 106

    Source:
    @verbatim
                      NSRDS - AICHE
                 Data Compilation Tables
                    of Properties of
                     Pure Compounds

        Design Institute for Physical Property Data
          American Institute of Chemical Engineers
                  345 East 47th Street
                New York, New York 10017

         National Standard Reference Data System
         American Institute of Chemical Engineers

          T.E. Daubert       -       R.P. Danner

            Department of Chemical Engineering
            The Pennsylvania State University
                University Park, PA 16802
    @endverbatim

\*---------------------------------------------------------------------------*/

#ifndef NSRDSfuncgSigma_H
#define NSRDSfuncgSigma_H

#include "thermophysicalFunction.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class NSRDSfuncgSigma Declaration
\*---------------------------------------------------------------------------*/

class NSRDSfuncgSigma
:
    public thermophysicalFunction
{
    // Private data

        // NSRDS function 106 coefficients
        scalar Tc_, a_, b_, c_, d_, e_;
        scalar sigma[56];


public:

    //- Runtime type information
    TypeName("NSRDSfuncgSigma");


    // Constructors

        //- Construct from components
        NSRDSfuncgSigma(scalar Tc, scalar a, scalar b, scalar c, scalar d, scalar e)
        :
            Tc_(Tc),
            a_(a),
            b_(b),
            c_(c),
            d_(d),
            e_(e)
        {}

        //- Construct from Istream
        NSRDSfuncgSigma(Istream& is)
        :
            Tc_(readScalar(is)),
            a_(readScalar(is)),
            b_(readScalar(is)),
            c_(readScalar(is)),
            d_(readScalar(is)),
            e_(readScalar(is))
        {}

        //- Construct from null & initialize from table
        NSRDSfuncgSigma() {
            sigma[0] = 2.71000e-02;
            sigma[1] = 2.71000e-02;
            sigma[2] = 2.71000e-02;
            sigma[3] = 2.71000e-02;
            sigma[4] = 2.71000e-02;
            sigma[5] = 2.71000e-02;
            sigma[6] = 2.71000e-02;
            sigma[7] = 2.71000e-02;
            sigma[8] = 2.71000e-02;
            sigma[9] = 2.71000e-02;
            sigma[10] = 2.71000e-02;
            sigma[11] = 2.71000e-02;
            sigma[12] = 2.71000e-02;
            sigma[13] = 2.71000e-02;
            sigma[14] = 2.71000e-02;
            sigma[15] = 2.71000e-02;
            sigma[16] = 2.71000e-02;
            sigma[17] = 2.71000e-02;
            sigma[18] = 2.71000e-02;
            sigma[19] = 2.71000e-02;
            sigma[20] = 2.71000e-02;
            sigma[21] = 2.71000e-02;
            sigma[22] = 2.71000e-02;
            sigma[23] = 2.60900e-02;
            sigma[24] = 2.50700e-02;
            sigma[25] = 2.40600e-02;
            sigma[26] = 2.30500e-02;
            sigma[27] = 2.20200e-02;
            sigma[28] = 2.10000e-02;
            sigma[29] = 1.99700e-02;
            sigma[30] = 1.89300e-02;
            sigma[31] = 1.79100e-02;
            sigma[32] = 1.68900e-02;
            sigma[33] = 1.58600e-02;
            sigma[34] = 1.48400e-02;
            sigma[35] = 1.38200e-02;
            sigma[36] = 1.28500e-02;
            sigma[37] = 1.19200e-02;
            sigma[38] = 1.10100e-02;
            sigma[39] = 1.01100e-02;
            sigma[40] = 9.29000e-03;
            sigma[41] = 8.46000e-03;
            sigma[42] = 7.70000e-03;
            sigma[43] = 6.95000e-03;
            sigma[44] = 6.22000e-03;
            sigma[45] = 5.58000e-03;
            sigma[46] = 4.92000e-03;
            sigma[47] = 4.27000e-03;
            sigma[48] = 3.65000e-03;
            sigma[49] = 3.07000e-03;
            sigma[50] = 2.50000e-03;
            sigma[51] = 1.94000e-03;
            sigma[52] = 1.39000e-03;
            sigma[53] = 8.80000e-04;
            sigma[54] = 3.80000e-04;
            sigma[55] = -9.50000e-05;
	}

    // Member Functions

        //- Evaluate the function and return the result
        scalar f(scalar, scalar T) const
        {
	    scalar sigma_ = 0.0;
      
	    for(int i=0; i<55; i++){
		   if(T>=10*i && T<10*(i+1)){
		   	sigma_ = sigma[i]+(T-10*i)*(sigma[i+1]-sigma[i])/10;
		   	break;
			}
		   }
	    return sigma_;
        }


        //- Write the function coefficients
        void writeData(Ostream& os) const
        {
            os  << Tc_ << token::SPACE
                << a_ << token::SPACE
                << b_ << token::SPACE
                << c_ << token::SPACE
                << d_ << token::SPACE
                << e_;
        }


    // Ostream Operator

        friend Ostream& operator<<(Ostream& os, const NSRDSfuncgSigma& f)
        {
            f.writeData(os);
            return os;
        }
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
